@@ -11,7 +11,7 @@ from tests.resources.helper_functions import get_assset_json_text
 
 def test_secret_store_encrypt_decrypt():
     metadata_json = get_assset_json_text(
-        'https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs'
+        'https://raw.githubusercontent.com/nevermined-io/docs/master/docs/architecture/specs'
         '/examples/access/v0.1/ddo1.json')
     document_id = hashlib.sha256((metadata_json + secrets.token_hex(32)).encode()).hexdigest()
     print(document_id)
